@@ -15,16 +15,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+import os.path
+
 APP_NAME = 'Mobius Forensic Toolkit'
 APP_VERSION = '${version}'
 APP_TITLE = 'Mobius v%s' % APP_VERSION
-APP_DATADIR='${install_data}/share/mobiusft'
-
-import os.path
+APP_DATADIR= os.path.join ('${install_data}', 'share', 'mobiusft')
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Return path to file/directory inside DATADIR
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 def get_data_path (*args):
   return os.path.join (APP_DATADIR, *args)
-
